# Example lab notebook

Created on: 2022-03-16

Author: mmiots9

## 2022-03-16

### add README

sha: 20143ed

Analysis file: `none`

Affected files
- A README.md

### First analysis

Create a fake output file

sha: 977558e

Analysis file: `analyses/first.Rmd`

Affected files
- A analyses/first.Rmd
- A output/out1.pdf

### new info file

sha: 9ffcab5

Analysis file: `none`

Affected files
- A info.txt